@@ -60,7 +60,7 @@ private:
     void setupGUILayout();
 
 protected:
-    virtual void closeEvent(QCloseEvent *event);
+    void closeEvent(QCloseEvent *event) override;
 
 private:
     int mMaxGameCapacity;
@@ -69,17 +69,17 @@ private:
     bool mGameAnim;
     bool mWaitForAll;
 
-    KBlocksScene *mpGameScene;
-    KBlocksView  *mpGameView;
+    KBlocksScene *mpGameScene = nullptr;
+    KBlocksView  *mpGameView = nullptr;
 
-    KBlocksGameLogic *mpGameLogic;
-    KBlocksPlayManager *mpPlayManager;
+    KBlocksGameLogic *mpGameLogic = nullptr;
+    KBlocksPlayManager *mpPlayManager = nullptr;
 
-    KBlocksKeyboardPlayer *mpKBPlayer;
-    KBlocksAIPlayer *mpAIPlayer;
+    KBlocksKeyboardPlayer *mpKBPlayer = nullptr;
+    KBlocksAIPlayer *mpAIPlayer = nullptr;
 
-    QAction *m_pauseAction;
-    QLabel *mScore;
+    QAction *m_pauseAction = nullptr;
+    QLabel *mScore = nullptr;
 };
 
 #endif
